Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(217)

Unified Diff: tools/telemetry/telemetry/internal/platform/profiler/android_screen_recorder_profiler.py

Issue 1522313002: [Android] Move screenshot and video_recorder into devil. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix video_recorder timing Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/telemetry/telemetry/internal/platform/android_platform_backend.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/telemetry/telemetry/internal/platform/profiler/android_screen_recorder_profiler.py
diff --git a/tools/telemetry/telemetry/internal/platform/profiler/android_screen_recorder_profiler.py b/tools/telemetry/telemetry/internal/platform/profiler/android_screen_recorder_profiler.py
index f67bd8c503f54058bd7008f3fed160057adbf37a..c1d40313544078a07939b9caa3d9159a967ffb6a 100644
--- a/tools/telemetry/telemetry/internal/platform/profiler/android_screen_recorder_profiler.py
+++ b/tools/telemetry/telemetry/internal/platform/profiler/android_screen_recorder_profiler.py
@@ -2,11 +2,11 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
# pylib may not be available if we're not in an Android checkout.
try:
- from pylib import screenshot
+ from devil.android.tools import video_recorder
except ImportError:
- screenshot = None
+ video_recorder = None
from telemetry.internal.platform import profiler
from telemetry.internal.backends.chrome import android_browser_finder
@@ -22,7 +22,7 @@ class AndroidScreenRecordingProfiler(profiler.Profiler):
super(AndroidScreenRecordingProfiler, self).__init__(
browser_backend, platform_backend, output_path, state)
self._output_path = output_path + '.mp4'
- self._recorder = screenshot.VideoRecorder(
+ self._recorder = video_recorder.VideoRecorder(
browser_backend.device,
megabits_per_second=_VIDEO_MEGABITS_PER_SECOND)
self._recorder.Start()
@@ -2,11 +2,11 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
-# pylib may not be available if we're not in an Android checkout.
+# devil may not be available if we're not in an Android checkout.
try:
« no previous file with comments | « tools/telemetry/telemetry/internal/platform/android_platform_backend.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698